==> summerd-sdk-1.2.11.tgz: package/server/middlewares/ssr.js <==
const fs = require('fs')
const LRU = require('lru-cache')
const { createBundleRenderer } = require('vue-server-renderer')
const { resolve, readFile } = require('summerd-sdk/utils')

// const serve = (path, cache) => Express.static(resolve(path), {
//   maxAge: cache && isProd ? 1000 * 60 * 60 * 24 * 30 : 2000000
// })

const createRenderer = (bundle, options) => {
  return createBundleRenderer(bundle, Object.assign(options, {
    runInNewContext: false,
    cache: LRU({
      max: 1000,
      maxAge: 1000 * 60 * 15,
    }),
    basedir: resolve('public'),
  }))
}

let renderer
// let readyPromise


const templatePath = resolve('index.template.html')
const bundle = JSON.parse(readFile(fs, 'vue-ssr-server-bundle.json'))

// const serverCompiler = webpack(serverConfig)
// const mfs = new MFS()
// serverCompiler.outputFileSystem = mfs
// serverCompiler.watch({}, (err, stats) => {
//   if (err) throw err
//   stats = stats.toJson()
//   if (stats.errors.length) return

//   console.log('server-dev...')
//   bundle = JSON.parse(readFile(mfs, 'vue-ssr-server-bundle.json'))
//   update()
// })

// 服务端渲染
renderer = createRenderer(bundle, options)
// readyPromise = setupDevServer(app, templatePath, (bundle, options) => {
//   renderer = createRenderer(bundle, options)
// })

const render = (req, res) => {
  const s = Date.now()
  res.setHeader('Content-Type', 'text/html')

  const context = {
    url: req.url,
  }

  renderer.renderToString(context, (err, html) => {
    if (err) {
      throw err
    }

    const { title } = context.meta.inject()

    res.send(html)

    if (!isProd) {
      console.log(`whole request: ${Date.now() - s}ms`)
    }
  })
}

module.exports = function proxyMiddleware (app) {
  app.get('*', (req, res) => {
    render(req, res)
    // readyPromise.then(() => render(req, res))
  })
}

==> summerd-sdk-1.2.13.tgz: package/server/middlewares/ssr.js <==
const fs = require('fs')
const LRU = require('lru-cache')
const { createBundleRenderer } = require('vue-server-renderer')
const { resolve, readFile } = require('summerd-sdk/utils')

// const serve = (path, cache) => Express.static(resolve(path), {
//   maxAge: cache && isProd ? 1000 * 60 * 60 * 24 * 30 : 2000000
// })

const createRenderer = (bundle, options) => {
  return createBundleRenderer(bundle, Object.assign(options, {
    runInNewContext: false,
    cache: LRU({
      max: 1000,
      maxAge: 1000 * 60 * 15,
    }),
    basedir: resolve('public'),
  }))
}

let renderer
// let readyPromise


const templatePath = resolve('index.template.html')
const bundle = JSON.parse(readFile(fs, 'vue-ssr-server-bundle.json'))

// const serverCompiler = webpack(serverConfig)
// const mfs = new MFS()
// serverCompiler.outputFileSystem = mfs
// serverCompiler.watch({}, (err, stats) => {
//   if (err) throw err
//   stats = stats.toJson()
//   if (stats.errors.length) return

//   console.log('server-dev...')
//   bundle = JSON.parse(readFile(mfs, 'vue-ssr-server-bundle.json'))
//   update()
// })

// 服务端渲染
renderer = createRenderer(bundle, {})
// readyPromise = setupDevServer(app, templatePath, (bundle, options) => {
//   renderer = createRenderer(bundle, options)
// })

const render = (req, res) => {
  const s = Date.now()
  res.setHeader('Content-Type', 'text/html')

  const context = {
    url: req.url,
  }

  renderer.renderToString(context, (err, html) => {
    if (err) {
      throw err
    }

    // const { title } = context.meta.inject()

    res.send(html)

    // if (!isProd) {
    //   console.log(`whole request: ${Date.now() - s}ms`)
    // }
  })
}

module.exports = function proxyMiddleware (req, res, next) {
  render(req, res)

  next()
}
